# Google Analytics Data Wrapper Library

A Python library to interact with Google Analytics data, providing a simple interface to pull reports and convert them into a table format.

## Features

- Pull reports from Google Analytics.
- Convert reports into a tabular format for easy data manipulation.

## Installation

To install the library, run:

```bash
pip install ganalytics

```

## Example
Refer to quickstart.py for example usage.